@@ -2,7 +2,7 @@
 require "gtk"
 
 -- test access to widget functions
-win = gtk.window_new(gtk.GTK_WINDOW_TOPLEVEL)
+win = gtk.window_new(gtk.WINDOW_TOPLEVEL)
 win:set_title("Hello")
 
 
